@@ -5,7 +5,7 @@ from snowflake.sqlalchemy import URL
 from sqlalchemy import create_engine
 import logging
 logger = logging.getLogger('snowflake.connector',)
-logger.setLevel(logging.warning())
+logger.setLevel(logging.warning(msg='what the fucking fuck Shimon are you doing?!'))
 
 
 # !conda install -y -c conda-forge pyarrow
